@@ -1,8 +1,10 @@
-__version__ = '0.1.7'
+__version__ = '0.2.0'
 
 # Re-export modules that we want to expose in a clean way
 from mmisdk.custodian_factory import CustodianFactory
 from mmisdk.qredo.qredo import Qredo
+from mmisdk.cactus.cactus import Cactus
 
 CustodianFactory
 Qredo
+Cactus
