@@ -17,13 +17,13 @@ class Transaction(BaseModel):
     id: str
     type: str
     from_: str
-    to: str
-    value: str
+    to: Optional[str]
+    value: Optional[str]
     gas: str
     gasPrice: Optional[str]
     maxPriorityFeePerGas: Optional[str]
     maxFeePerGas: Optional[str]
-    nonce: str
-    data: str
-    hash: str
+    nonce: Optional[str]
+    data: Optional[str]
+    hash: Optional[str]
     status: TransactionStatus
