@@ -14,11 +14,11 @@ class BaseTxParams(BaseModel):
 
 
 class LegacyTxParams(BaseTxParams):
-    type: Optional[str]
+    type = 1
     gasPrice: str
 
 
 class EIP11559TxParams(BaseTxParams):
-    type: str
+    type = 2
     maxPriorityFeePerGas: str
     maxFeePerGas: str
