@@ -1,22 +1,30 @@
 import requests
-
+from typing import List, Union
 from mmisdk.common.custodian import Custodian
 from mmisdk.common.transaction import Transaction
 from mmisdk.common.transaction_params import EIP11559TxParams
 from mmisdk.common.transaction_params import LegacyTxParams
-from mmisdk.qredo.map_transaction_status import map_transaction_status
-from mmisdk.qredo.qredo_tansaction import QredoTransaction
-from mmisdk.qredo.qredo_tx_details import QredoTxDetails
+from mmisdk.qredo.dtos import QredoCreateTxExtramParams, QredoTransaction
+from mmisdk.utils.map_transaction_status import map_transaction_status
 
 
 class Qredo(Custodian):
 
     def __create_access_token(self):
+        """Internal method that creates an access token, necessary to authenticate other calls against Qredo's API.
+
+        Returns:
+            The access token as a string.
+        """
         url = self.api_url+'/connect/token'
         querystring = {"grant_type": "refresh_token",
                        "refresh_token": self.refresh_token}
         payload = ""
+
         response = requests.post(url, data=payload, params=querystring)
+        if (response.status_code != 200):
+            raise requests.HTTPError(
+                f"Couldn't create the access token, {response.text}")
 
         access_token = response.json()["access_token"]
         return access_token
@@ -29,7 +37,7 @@ class Qredo(Custodian):
             "Authorization": 'Bearer ' + access_token
         }
 
-    def get_transaction(self, transaction_id):
+    def get_transaction(self, transaction_id, chain_id=1) -> Transaction:
         url = self.api_url + '/connect/transaction/' + transaction_id
         payload = ""
         headers = self.__get_headers()
@@ -46,12 +54,16 @@ class Qredo(Custodian):
 
         return self.__map_qredo_transaction_to_transaction(qredo_transaction)
 
-    def create_transaction(self, qredo_tx_details, tx_params):
+    def get_transactions(self, chain_id=1) -> List[Transaction]:
+        raise requests.HTTPError("Not implemented")
+
+    def create_transaction(self, tx_params: Union[LegacyTxParams, EIP11559TxParams], extra_params: QredoCreateTxExtramParams) -> Transaction:
         url = self.api_url + "/connect/transaction"
         headers = self.__get_headers()
 
         # Parse and type check params
-        qredo_tx_details_parsed = QredoTxDetails(**qredo_tx_details)
+        qredo_tx_details_parsed = QredoCreateTxExtramParams(**extra_params)
+        tx_params["from_"] = tx_params["from"]
         tx_params_parsed = EIP11559TxParams(
             **tx_params) if 'type' in tx_params and tx_params['type'] == "2" else LegacyTxParams(**tx_params)
 
